@@ -1,4 +1,4 @@
-# @(#)Ident: CPANTesting.pm 2013-07-31 20:09 pjf ;
+# @(#)Ident: CPANTesting.pm 2013-08-04 08:39 pjf ;
 
 package CPANTesting;
 
@@ -14,15 +14,15 @@ sub is_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
 sub should_abort {
    is_testing() or return 0;
 
-   $host eq q(xphvmfred)
-      and return "ABORT: cc06993e-a5e9-11e2-83b7-87183f85d660";
+   $host eq q(xphvmfred) and return
+      "ABORT: ${host} - cc06993e-a5e9-11e2-83b7-87183f85d660";
    $host =~ m{ nigelhorne }mx
       and return "ABORT: 52e56e36-f9f4-11e2-90a1-fb47fbca4e08";
    return 0;
 }
 
 sub test_exceptions {
-   my $p = shift; my $perl_ver = $p->{requires}->{perl};
+   my $p = shift; my $perl_ver = $p->{_min_perl_ver} || $p->{requires}->{perl};
 
    is_testing()        or  return 0;
    $] < $perl_ver      and return "TESTS: Perl minimum ${perl_ver}";
